Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon SageMaker with MLflow.

Actions, resources, and condition keys for Amazon SageMaker with MLflow - Service Authorization Reference

# Actions, resources, and condition keys for Amazon SageMaker with MLflow

Amazon SageMaker with MLflow (service prefix: `sagemaker-mlflow` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon SageMaker with MLflow
- Resource types defined by Amazon SageMaker with MLflow
- Condition keys for Amazon SageMaker with MLflow

## Actions defined by Amazon SageMaker with MLflow

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AccessUI | Grants permission to access the MLflow UI | Read |  |  |
CreateExperiment | Grants permission to create an MLflow experiment | Write | mlflow-tracking-server* |  |
CreateModelVersion | Grants permission to create a new model version | Write | mlflow-tracking-server* |  |
CreateRegisteredModel | Grants permission to create a registered model | Write | mlflow-tracking-server* |  |
CreateRun | Grants permission to create a new run within an experiment | Write | mlflow-tracking-server* |  |
DeleteExperiment | Grants permission to mark an MLflow experiment for deletion | Write | mlflow-tracking-server* |  |
DeleteModelVersion | Grants permission to delete a model version | Write | mlflow-tracking-server* |  |
DeleteModelVersionTag | Grants permission to delete a model version tag | Write | mlflow-tracking-server* |  |
DeleteRegisteredModel | Grants permission to delete a registered model | Write | mlflow-tracking-server* |  |
DeleteRegisteredModelAlias | Grants permission to delete a registered model alias | Write | mlflow-tracking-server* |  |
DeleteRegisteredModelTag | Grants permission to delete a registered model tag | Write | mlflow-tracking-server* |  |
DeleteRun | Grants permission to mark a run for deletion | Write | mlflow-tracking-server* |  |
DeleteTag | Grants permission to delete a tag on a run | Write | mlflow-tracking-server* |  |
GetDownloadURIForModelVersionArtifacts | Grants permission to get a URI to download model artifacts for a specific model version | Read | mlflow-tracking-server* |  |
GetExperiment | Grants permission to get metadata for an MLflow experiment | Read | mlflow-tracking-server* |  |
GetExperimentByName | Grants permission to get metadata for an MLflow experiment by name | Read | mlflow-tracking-server* |  |
GetLatestModelVersions | Grants permission to get the latest model versions | List | mlflow-tracking-server* |  |
GetMetricHistory | Grants permission to get a list of all values for the specified metric for a given run | Read | mlflow-tracking-server* |  |
GetModelVersion | Grants permission to get a model version by model name and version | Read | mlflow-tracking-server* |  |
GetModelVersionByAlias | Grants permission to get model version by alias in MLflow | Read | mlflow-tracking-server* |  |
GetRegisteredModel | Grants permission to get a registered model | Read | mlflow-tracking-server* |  |
GetRun | Grants permission to get metadata, metrics, parameters, and tags for a run | Read | mlflow-tracking-server* |  |
ListArtifacts | Grants permission to list artifacts for a run | List | mlflow-tracking-server* |  |
LogBatch | Grants permission to log a batch of metrics, parameters, and tags for a run | Write | mlflow-tracking-server* |  |
LogInputs | Grants permission to log inputs for a run | Write | mlflow-tracking-server* |  |
LogMetric | Grants permission to log a metric for a run | Write | mlflow-tracking-server* |  |
LogModel | Grants permission to log the model associated with a run | Write | mlflow-tracking-server* |  |
LogParam | Grants permission to log a parameter tracked during a run | Write | mlflow-tracking-server* |  |
RenameRegisteredModel | Grants permission to rename a registered model | Write | mlflow-tracking-server* |  |
RestoreExperiment | Grants permission to restore an experiment marked for deletion | Write | mlflow-tracking-server* |  |
RestoreRun | Grants permission to restore a deleted run | Write | mlflow-tracking-server* |  |
SearchExperiments | Grants permission to search for MLflow experiments | Read | mlflow-tracking-server* |  |
SearchModelVersions | Grants permission to search for a model version | Read | mlflow-tracking-server* |  |
SearchRegisteredModels | Grants permission to search for registered models in MLflow | Read | mlflow-tracking-server* |  |
SearchRuns | Grants permission to search for runs that satisfy expressions | Read | mlflow-tracking-server* |  |
SetExperimentTag | Grants permission to set a tag on an experiment | Write | mlflow-tracking-server* |  |
SetModelVersionTag | Grants permission to set a tag for the model version | Write | mlflow-tracking-server* |  |
SetRegisteredModelAlias | Grants permission to set a registered model alias | Write | mlflow-tracking-server* |  |
SetRegisteredModelTag | Grants permission to set a tag for a registered model | Write | mlflow-tracking-server* |  |
SetTag | Grants permission to set a tag on a run | Write | mlflow-tracking-server* |  |
TransitionModelVersionStage | Grants permission to transition a model version to a particular stage | Write | mlflow-tracking-server* |  |
UpdateExperiment | Grants permission to update the metadata for an MLflow experiment | Write | mlflow-tracking-server* |  |
UpdateModelVersion | Grants permission to update the model version | Write | mlflow-tracking-server* |  |
UpdateRegisteredModel | Grants permission to update a registered model | Write | mlflow-tracking-server* |  |
UpdateRun | Grants permission to update run metadata | Write | mlflow-tracking-server* |  |

## Resource types defined by Amazon SageMaker with MLflow

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
mlflow-tracking-server | `arn:$ { Partition}:sagemaker:$ { Region}:$ { Account}:mlflow-tracking-server/$ { MlflowTrackingServerName}` |

## Condition keys for Amazon SageMaker with MLflow

SageMaker MLflow has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.